@@ -85,7 +85,7 @@
 #define   MCHelpSwILOG       L"\n  ilog[name]    Log errors to file"
 #define   MCHelpSwINUL       L"\n  inul          Disable all messages"
 #define   MCHelpSwIOFF       L"\n  ioff[n]       Turn PC off after completing an operation"
-#define   MCHelpSwISND       L"\n  isnd          Control notification sounds"
+#define   MCHelpSwISND       L"\n  isnd[-]       Control notification sounds"
 #define   MCHelpSwIVER       L"\n  iver          Display the version number"
 #define   MCHelpSwK          L"\n  k             Lock archive"
 #define   MCHelpSwKB         L"\n  kb            Keep broken extracted files"
@@ -131,7 +131,7 @@
 #define   MCHelpSwTO         L"\n  to[mcao]<t>   Process files older than <t> time"
 #define   MCHelpSwTA         L"\n  ta[mcao]<d>   Process files modified after <d> YYYYMMDDHHMMSS date"
 #define   MCHelpSwTB         L"\n  tb[mcao]<d>   Process files modified before <d> YYYYMMDDHHMMSS date"
-#define   MCHelpSwTS         L"\n  ts[m,c,a]     Save or restore file time (modification, creation, access)"
+#define   MCHelpSwTS         L"\n  ts[m,c,a,p]   Save or restore time (modification, creation, access, preserve)"
 #define   MCHelpSwU          L"\n  u             Update files"
 #define   MCHelpSwV          L"\n  v             Create volumes with size autodetection or list all volumes"
 #define   MCHelpSwVUnr       L"\n  v             List all volumes"
@@ -203,7 +203,6 @@
 #define   MErrOpenFile       L"file"
 #define   MAddNoFiles        L"\nWARNING: No files"
 #define   MMdfEncrSol        L"\n%s: encrypted"
-#define   MCannotMdfEncrSol  L"\nCannot modify solid archive containing encrypted files"
 #define   MAddAnalyze        L"\nAnalyzing archived files: "
 #define   MRepacking         L"\nRepacking archived files: "
 #define   MCRCFailed         L"\n%-20s - checksum error"
@@ -342,7 +341,7 @@
 #define   MFAT32Size         L"\nWARNING: FAT32 file system does not support 4 GB or larger files"
 #define   MErrChangeAttr     L"\nWARNING: Cannot change attributes of %s"
 #define   MWrongSFXVer       L"\nERROR: default SFX module does not support RAR %d.%d archives"
-#define   MCannotEncName     L"\nCannot encrypt archive already containing encrypted files"
+#define   MHeadEncMismatch   L"\nCannot change the header encryption mode in already encrypted archive"
 #define   MCannotEmail       L"\nCannot email the file %s"
 #define   MCopyrightS        L"\nRAR SFX archive" 
 #define   MSHelpCmd          L"\n\n<Commands>" 
